Index: trunk/MagicSoft/Mars/mbase/MLog.cc
===================================================================
--- trunk/MagicSoft/Mars/mbase/MLog.cc	(revision 2744)
+++ trunk/MagicSoft/Mars/mbase/MLog.cc	(revision 2772)
@@ -16,7 +16,7 @@
 !
 !
-!   Author(s): Thomas Bretz  12/2000 <mailto:tbretz@uni-sw.gwdg.de>
-!
-!   Copyright: MAGIC Software Development, 2000-2001
+!   Author(s): Thomas Bretz, 12/2000 <mailto:tbretz@astro.uni-wuerzburg.de>
+!
+!   Copyright: MAGIC Software Development, 2000-2004
 !
 !
Index: trunk/MagicSoft/Mars/mbase/MParContainer.h
===================================================================
--- trunk/MagicSoft/Mars/mbase/MParContainer.h	(revision 2744)
+++ trunk/MagicSoft/Mars/mbase/MParContainer.h	(revision 2772)
@@ -110,4 +110,6 @@
     virtual Bool_t AsciiWrite(ostream &out) const;
 
+    Int_t Read(const char *name=NULL) { return TObject::Read(name?name:(const char*)fName); }
+
     virtual void GetNames(TObjArray &arr) const;
     virtual void SetNames(TObjArray &arr);
Index: trunk/MagicSoft/Mars/mbase/MStatusDisplay.h
===================================================================
--- trunk/MagicSoft/Mars/mbase/MStatusDisplay.h	(revision 2744)
+++ trunk/MagicSoft/Mars/mbase/MStatusDisplay.h	(revision 2772)
@@ -162,5 +162,5 @@
      void SetNoContextMenu(Bool_t flag=kTRUE);
 
-     Int_t  SaveAsPS(TString name="") { return SaveAsPS(-1, name); }
+     Int_t  SaveAsPS(TString name="", const TString addon="") { return SaveAsPS(-1, name, addon); }
      Bool_t SaveAsGIF(TString name="") { return SaveAsGIF(-1, name); }
      Bool_t SaveAsC(TString name="") { return SaveAsC(-1, name); }
@@ -168,5 +168,5 @@
      Int_t  PrintToLpr() { return PrintToLpr(-1); }
 
-     Int_t  SaveAsPS(Int_t num, TString name="");
+     Int_t  SaveAsPS(Int_t num, TString name="", const TString addon="");
      Bool_t SaveAsGIF(Int_t num, TString name="");
      Bool_t SaveAsC(Int_t num, TString name="");

Index: trunk/MagicSoft/Mars/mbase/MStatusDisplay.cc
===================================================================
--- trunk/MagicSoft/Mars/mbase/MStatusDisplay.cc	(revision 2744)
+++ trunk/MagicSoft/Mars/mbase/MStatusDisplay.cc	(revision 2772)
@@ -1763,5 +1763,8 @@
 // To write all tabs you can also use SaveAsPS(name)
 //
-Int_t MStatusDisplay::SaveAsPS(Int_t num, TString name)
+// If the third argument is given a bottom line is drawn with the text
+// under it.
+//
+Int_t MStatusDisplay::SaveAsPS(Int_t num, TString name, const TString addon)
 {
     SetStatusLine1("Writing Postscript file...");
@@ -1830,9 +1833,9 @@
 
         //
         // 26 is used here to scale the canvas into a height of 26,
         // such that the page title can be set above the canvas...
         //
-        Float_t psw = 26; //29.7; // A4 - width
-        Float_t psh = 21.0; // A4 - height
+        Float_t psw = 28.0; // A4 - width (29.7)
+        Float_t psh = 21.0; // A4 - height (21.0)
 
         const Float_t cw = c->GetWw();
@@ -1853,4 +1856,5 @@
         CanvasSetFillColor(*n, kWhite);
         l.Add(n);
+
         //
         // Paint canvas into root file
@@ -1878,10 +1882,17 @@
         ps.SetTextFont(22);
         ps.SetTextAlign(11); // left top
-        ps.TextNDC(0, 1.02, TString("  ")+n->GetName());
+        ps.TextNDC(0, 1.015, TString("  ")+n->GetName());
         ps.SetTextAlign(21); // cent top
-        ps.TextNDC(0.5, 1.02, TString("MARS - Magic Analysis and Reconstruction Software - ")+d.AsString());
+        ps.TextNDC(0.5, 1.015, TString("MARS - Magic Analysis and Reconstruction Software - ")+d.AsString());
         ps.SetTextAlign(31); // right top
-        ps.TextNDC(1, 1.02, Form("Page No.%i (%i)  ", page++, i));
-        line.PaintLineNDC(0, 1.015, 1, 1.015);
+        ps.TextNDC(1, 1.015, Form("Page No.%i (%i)  ", page++, i));
+        line.PaintLineNDC(0, 1.01, 1, 1.01);
+
+        if (!addon.IsNull())
+        {
+            line.PaintLineNDC(0, -0.00, 1, -0.00);
+            ps.SetTextAlign(23); // cent bottom
+            ps.TextNDC(0.5, -0.005, addon);
+        }
 
         //
@@ -1830,9 +1833,9 @@
 
         //
-        // 26 is used here to scale the canvas into a height of 26,
+        // 28 is used here to scale the canvas into a height of 28,
         // such that the page title can be set above the canvas...
         //